https://git.reactos.org/?p=reactos.git;a=commitdiff;h=ec68a3311fed47ac7409fccc126ca9b51e715607

commit ec68a3311fed47ac7409fccc126ca9b51e715607
Author:     Jérôme Gardou <[email protected]>
AuthorDate: Wed Apr 28 23:52:45 2021 +0200
Commit:     Jérôme Gardou <[email protected]>
CommitDate: Mon May 3 22:00:57 2021 +0200

    [CMAKE] Use SEH exceptions for c++ in clang amd64 build
---
 sdk/cmake/gcc.cmake | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/sdk/cmake/gcc.cmake b/sdk/cmake/gcc.cmake
index f542d34ef19..298a867bb45 100644
--- a/sdk/cmake/gcc.cmake
+++ b/sdk/cmake/gcc.cmake
@@ -480,8 +480,8 @@ 
add_compile_options("$<$<COMPILE_LANGUAGE:CXX>:$<IF:$<BOOL:$<TARGET_PROPERTY:WIT
 # We disable exceptions, unless said so
 
add_compile_options("$<$<COMPILE_LANGUAGE:CXX>:$<IF:$<BOOL:$<TARGET_PROPERTY:WITH_CXX_EXCEPTIONS>>,-fexceptions,-fno-exceptions>>")
 
-# G++ shipped with ROSBE uses sjlj exceptions. Tell Clang it is so
-if (CLANG)
+# G++ shipped with ROSBE uses sjlj exceptions on i386. Tell Clang it is so
+if (CLANG AND (ARCH STREQUAL "i386"))
     
add_compile_options("$<$<AND:$<COMPILE_LANGUAGE:CXX>,$<BOOL:$<TARGET_PROPERTY:WITH_CXX_EXCEPTIONS>>>:-fsjlj-exceptions>")
 endif()
 

Reply via email to